searchData={"items":[{"type":"module","title":"HTML2Text","doc":"A native-implemented HTML to plain text converter using Rust NIF.\n\nThis module provides functionality to convert HTML documents to plain text format\nwith configurable line width wrapping. It uses the Rust `html2text` crate under\nthe hood for high-performance HTML parsing and text extraction.\n\nThe converter handles HTML entities, removes tags, and formats the output as\nreadable plain text while preserving the logical structure of the content.\n\nSee: https://github.com/jugglerchris/rust-html2text","ref":"HTML2Text.html"},{"type":"function","title":"HTML2Text.convert/2","doc":"Converts HTML content to plain text with configurable line width.\n\nThis function converts HTML content to plain text and optionally wraps lines at the\nspecified width. The width can be either a positive integer representing the maximum\nnumber of characters per line, or `:infinity` for unlimited line width.","ref":"HTML2Text.html#convert/2"},{"type":"function","title":"Parameters - HTML2Text.convert/2","doc":"- `html` - A binary containing the HTML content to convert\n- `width` - Either a positive integer for line width or `:infinity` for unlimited width","ref":"HTML2Text.html#convert/2-parameters"},{"type":"function","title":"Return Value - HTML2Text.convert/2","doc":"Returns a string containing the plain text representation of the HTML content.","ref":"HTML2Text.html#convert/2-return-value"},{"type":"function","title":"Examples - HTML2Text.convert/2","doc":"# Converting with specific width\n    iex> html = \" Welcome to Our Amazing Website  This is a comprehensive guide that covers everything you need to know about our services and products. \"\n    iex> HTML2Text.convert(html, 30)\n    \"# Welcome to Our Amazing\\n# Website\\n\\nThis is a comprehensive guide\\nthat covers everything you\\nneed to know about our\\nservices and products.\\n\"\n\n    # Converting with unlimited width\n    iex> html = \"  Important:  Please read all the terms and conditions carefully before proceeding with your purchase. \"\n    iex> HTML2Text.convert(html, :infinity)\n    \"**Important:** Please read all the terms and conditions carefully before proceeding with your purchase.\\n\"\n\n    # Converting lists and complex HTML\n    iex> html = \"  First item with some detailed description  Second item that also has quite a bit of text  Third item  \"\n    iex> HTML2Text.convert(html, 25)\n    \"* First item with some\\n  detailed description\\n* Second item that also\\n  has quite a bit of text\\n* Third item\\n\"\n\n    # Converting tables and structured content\n    iex> html = \"   Product Name  Description  Price    Widget  A useful widget for everyday tasks  $19.99   \"\n    iex> HTML2Text.convert(html, 50)\n    \"\"\"\n    ───────────┬────────────────────────────────┬─────\n    Product    │Description                     │Price\n    Name       │                                │     \n    ───────────┼────────────────────────────────┼─────\n    Widget     │A useful widget for everyday    │$19.9\n               │tasks                           │9    \n    ───────────┴────────────────────────────────┴─────\n    \"\"\"","ref":"HTML2Text.html#convert/2-examples"},{"type":"extras","title":"README","doc":"# HTML2Text\n[![Hex.pm](https://img.shields.io/hexpm/v/html2text.svg)](https://hex.pm/packages/html2text)\n\nA high-performance Elixir library for converting HTML documents to plain text format using Rust NIFs (Native Implemented Functions).","ref":"readme.html"},{"type":"extras","title":"Overview - README","doc":"HTML2Text provides a simple and efficient way to extract readable plain text from HTML content. It leverages the power of Rust's [html2text](https://crates.io/crates/html2text) crate to deliver fast HTML parsing and text extraction while maintaining the logical structure and readability of the content.","ref":"readme.html#overview"},{"type":"extras","title":"Installation - README","doc":"Add `html2text` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:html2text, \"~> 0.1\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"The library provides a single main function `HTML2Text.convert/2` that takes HTML content and a width parameter.\n\n```elixir\n# Convert with specific line width\nhtml = \" Welcome  This is a sample paragraph with some content. \"\ntext = HTML2Text.convert(html, 30)\nIO.puts(text)\n# Output:\n# # Welcome\n#\n# This is a sample paragraph\n# with some content.\n\n\n# Convert with unlimited width\ntext = HTML2Text.convert(html, :infinity)\nIO.puts(text)\n# Output:\n# # Welcome\n#\n# This is a sample paragraph with some content.\n\nhtml = \"\"\"\n \n   Article Title \n    Introduction:  This article covers important topics. \n\n   Section 1 \n   Content with  emphasis  and  links . \n\n   \n     Point one \n     Point two \n   \n\n   Section 2: Simple Table \n   Key metrics overview: \n\n   \n     \n       \n         Metric \n         Value \n         Change \n       \n     \n     \n       \n         Users \n         15,300 \n         +12% \n       \n       \n         Sessions \n         48,500 \n         -5% \n       \n     \n   \n\n   Conclusion \n   This article provided an overview of important web technologies and some key statistics. \n \n\"\"\"\n\ntext = HTML2Text.convert(html, 70)\nIO.puts(text)\n\n# Output:\n# # Article Title\n#\n# **Introduction:** This article covers important topics.\n#\n#","ref":"readme.html#usage"},{"type":"extras","title":"Section 1 - README","doc":"#\n# Content with *emphasis* and [links][1].\n# * Point one\n# * Point two\n#\n#","ref":"readme.html#section-1"},{"type":"extras","title":"Section 2: Simple Table - README","doc":"#\n# Key metrics overview:\n#\n# ────────┬──────┬──────\n# Metric  │Value │Change\n# ────────┼──────┼──────\n# Users   │15,300│+12%  \n# ────────┼──────┼──────\n# Sessions│48,500│-5%   \n# ────────┴──────┴──────\n#\n#","ref":"readme.html#section-2-simple-table"},{"type":"extras","title":"Conclusion - README","doc":"#\n# This article provided an overview of important web technologies and\n# some key statistics.\n#\n# [1]: http://example.com\n```","ref":"readme.html#conclusion"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}